Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.cpp	(revision 84582)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.cpp	(revision 84583)
@@ -42,23 +42,4 @@
 #include "iprt/assert.h"
 
-UIChooserDisabledItemEffect::UIChooserDisabledItemEffect(int iBlurRadius, QObject *pParent /* = 0 */)
-    :QGraphicsEffect(pParent)
-    , m_iBlurRadius(iBlurRadius)
-{
-}
-
-void UIChooserDisabledItemEffect::draw(QPainter *painter)
-{
-    QPoint offset;
-    QPixmap pixmap;
-    /* Get the original pixmap: */
-    pixmap = sourcePixmap( Qt::LogicalCoordinates, &offset );
-    QImage resultImage;
-    /* Apply our blur and grayscale filters to the original pixmap: */
-    UIImageTools::blurImage(pixmap.toImage(), resultImage, m_iBlurRadius);
-    pixmap.convertFromImage(UIImageTools::toGray(resultImage));
-    /* Use the filtered pixmap: */
-    painter->drawPixmap( offset, pixmap );
-}
 
 /** QAccessibleObject extension used as an accessibility interface for Chooser-view items. */
@@ -210,4 +191,29 @@
     UIChooserItem *item() const { return qobject_cast<UIChooserItem*>(object()); }
 };
+
+
+/*********************************************************************************************************************************
+*   Class UIChooserDisabledItemEffect implementation.                                                                            *
+*********************************************************************************************************************************/
+
+UIChooserDisabledItemEffect::UIChooserDisabledItemEffect(int iBlurRadius, QObject *pParent /* = 0 */)
+    : QGraphicsEffect(pParent)
+    , m_iBlurRadius(iBlurRadius)
+{
+}
+
+void UIChooserDisabledItemEffect::draw(QPainter *pPainter)
+{
+    QPoint offset;
+    QPixmap pixmap;
+    /* Get the original pixmap: */
+    pixmap = sourcePixmap(Qt::LogicalCoordinates, &offset);
+    QImage resultImage;
+    /* Apply our blur and grayscale filters to the original pixmap: */
+    UIImageTools::blurImage(pixmap.toImage(), resultImage, m_iBlurRadius);
+    pixmap.convertFromImage(UIImageTools::toGray(resultImage));
+    /* Use the filtered pixmap: */
+    pPainter->drawPixmap(offset, pixmap);
+}
 
 
@@ -311,9 +317,13 @@
             m_pHoveringMachine->start();
         }
-    }
-    /* Allocate the effect instance which we use when the item is marked as disablec: */
-    m_pDisabledEffect = new UIChooserDisabledItemEffect(1 /* Blur Radius */);
-    setGraphicsEffect(m_pDisabledEffect);
-    m_pDisabledEffect->setEnabled(false);
+
+        /* Allocate the effect instance which we use when the item is marked as disabled: */
+        m_pDisabledEffect = new UIChooserDisabledItemEffect(1 /* Blur Radius */);
+        if (m_pDisabledEffect)
+        {
+            setGraphicsEffect(m_pDisabledEffect);
+            m_pDisabledEffect->setEnabled(node()->isDisabled());
+        }
+    }
 }
 
@@ -402,8 +412,8 @@
 }
 
-void UIChooserItem::disableEnableItem(bool fDisabled)
+void UIChooserItem::setDisabledEffect(bool fOn)
 {
     if (m_pDisabledEffect)
-        m_pDisabledEffect->setEnabled(fDisabled);
+        m_pDisabledEffect->setEnabled(fOn);
 }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNode.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNode.cpp	(revision 84582)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserNode.cpp	(revision 84583)
@@ -82,4 +82,4 @@
     m_fDisabled = fDisabled;
     if (m_pItem)
-        m_pItem->disableEnableItem(m_fDisabled);
+        m_pItem->setDisabledEffect(m_fDisabled);
 }

Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h	(revision 84582)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserItem.h	(revision 84583)
@@ -50,5 +50,7 @@
 class UIChooserNode;
 
-/** A simple QGraphicsEffect extension to mark disabled UIChooserItems. Applies blur and gray scale filters. */
+
+/** A simple QGraphicsEffect extension to mark disabled UIChooserItem.
+  * @note Applies blur and gray scale filters. */
 class UIChooserDisabledItemEffect : public QGraphicsEffect
 {
@@ -57,9 +59,16 @@
 public:
 
+    /** Constructs blur effect passing @a pParent to the base-class.
+      * @param  iBlurRadius  Brings the blur effect radius. */
     UIChooserDisabledItemEffect(int iBlurRadius, QObject *pParent = 0);
 
 protected:
 
-    virtual void draw(QPainter *painter);
+    /** Draws effect with passed @a pPainter. */
+    virtual void draw(QPainter *pPainter);
+
+private:
+
+    /** Holds the blur effect radius. */
     int m_iBlurRadius;
 };
@@ -145,6 +154,6 @@
           * @note  Base-class implementation does nothing. */
         virtual void installEventFilterHelper(QObject *pSource) { Q_UNUSED(pSource); }
-        /** Enables the visual effect for disabled item. */
-        void disableEnableItem(bool fDisabled);
+        /** Defines whether visual effect for disabled item is @a fOn. */
+        void setDisabledEffect(bool fOn);
     /** @} */
 
@@ -300,20 +309,20 @@
 
         /** Holds whether item is hovered. */
-        bool                m_fHovered;
+        bool                         m_fHovered;
         /** Holds the hovering animation machine instance. */
-        QStateMachine      *m_pHoveringMachine;
+        QStateMachine               *m_pHoveringMachine;
         /** Holds the forward hovering animation instance. */
-        QPropertyAnimation *m_pHoveringAnimationForward;
+        QPropertyAnimation          *m_pHoveringAnimationForward;
         /** Holds the backward hovering animation instance. */
-        QPropertyAnimation *m_pHoveringAnimationBackward;
+        QPropertyAnimation          *m_pHoveringAnimationBackward;
         /** Holds the animation duration. */
-        int                 m_iAnimationDuration;
+        int                          m_iAnimationDuration;
         /** Holds the default animation value. */
-        int                 m_iDefaultValue;
+        int                          m_iDefaultValue;
         /** Holds the hovered animation value. */
-        int                 m_iHoveredValue;
+        int                          m_iHoveredValue;
         /** Holds the animated value. */
-        int                 m_iAnimatedValue;
-        /** Holds the pointer to blur effect instance. */
+        int                          m_iAnimatedValue;
+        /** Holds the blur effect instance. */
         UIChooserDisabledItemEffect *m_pDisabledEffect;
     /** @} */